@@ -1,11 +1,14 @@
+# -*- coding: utf-8
+from __future__ import unicode_literals
+
 import os
 import argparse
 
+from . import _iterate_over_files, _smart_open
 from .precisecodevillemerge import Weave
 from .config import FragmentsConfig
 from .diff import _diff_group, _split_diff
 from .color import Prompt
-from . import _iterate_over_files
 
 
 def apply(*args):
@@ -52,9 +55,9 @@ def apply(*args):
         return
 
     old_revision = 1
-    weave.add_revision(old_revision, open(old_path, 'r').readlines(), [])
+    weave.add_revision(old_revision, _smart_open(old_path, 'r').readlines(), [])
     new_revision = 2
-    weave.add_revision(new_revision, open(changed_path, 'r').readlines(), [])
+    weave.add_revision(new_revision, _smart_open(changed_path, 'r').readlines(), [])
 
     diff = weave.merge(old_revision, new_revision)
 
@@ -143,14 +146,14 @@ def apply(*args):
         if other_path == changed_path:
             continue # don't try to apply changes to ourself
         current_revision += 1
-        weave.add_revision(current_revision, open(other_path, 'r').readlines(), [])
+        weave.add_revision(current_revision, _smart_open(other_path, 'r').readlines(), [])
         merge_result = weave.cherry_pick(changed_revision, current_revision) # Can I apply changes in changed_revision onto this other file?
         if len(merge_result) == 1 and isinstance(merge_result[0], tuple):
             # total conflict, skip
             yield "Changes in '%s' cannot apply to '%s', skipping" % (os.path.relpath(changed_path), os.path.relpath(other_path))
         elif tuple in set(type(mr) for mr in merge_result):
             # some conflicts exist
-            with open(other_path, 'w') as other_file:
+            with _smart_open(other_path, 'w') as other_file:
                 for line_or_conflict in merge_result:
                     if isinstance(line_or_conflict, tuple):
                         other_file.write('>'*7 + '\n')
@@ -165,6 +168,6 @@ def apply(*args):
             yield "Conflict merging '%s' into '%s'" % (os.path.relpath(changed_path), os.path.relpath(other_path))
         else:
             # Merge is clean:
-            with open(other_path, 'w') as other_file:
+            with _smart_open(other_path, 'w') as other_file:
                 other_file.writelines(merge_result)
             yield "Changes in '%s' applied cleanly to '%s'" % (os.path.relpath(changed_path), os.path.relpath(other_path))
